diff libpurple/protocols/qq/send_file.h @ 15822:32c366eeeb99

sed -ie 's/gaim/purple/g'
author Sean Egan <seanegan@gmail.com>
date Mon, 19 Mar 2007 07:01:17 +0000
parents 5fe8042783c1
children 44b4e8bd759b
line wrap: on
line diff
--- a/libpurple/protocols/qq/send_file.h	Mon Mar 19 06:11:46 2007 +0000
+++ b/libpurple/protocols/qq/send_file.h	Mon Mar 19 07:01:17 2007 +0000
@@ -1,9 +1,9 @@
 /**
  * @file send_file.h
  *
- * gaim
+ * purple
  *
  * Gaim is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
  *
@@ -67,19 +67,19 @@
 } ft_info;
 
 void qq_process_recv_file_accept(guint8 *data, guint8 **cursor, gint data_len, 
-		guint32 sender_uid, GaimConnection *gc);
+		guint32 sender_uid, PurpleConnection *gc);
 void qq_process_recv_file_reject(guint8 *data, guint8 **cursor, gint data_len, 
-		guint32 sender_uid, GaimConnection *gc);
+		guint32 sender_uid, PurpleConnection *gc);
 void qq_process_recv_file_cancel(guint8 *data, guint8 **cursor, gint data_len, 
-		guint32 sender_uid, GaimConnection *gc);
+		guint32 sender_uid, PurpleConnection *gc);
 void qq_process_recv_file_request(guint8 *data, guint8 **cursor, gint data_len, 
-		guint32 sender_uid, GaimConnection *gc);
+		guint32 sender_uid, PurpleConnection *gc);
 void qq_process_recv_file_notify(guint8 *data, guint8 **cursor, gint data_len, 
-		guint32 sender_uid, GaimConnection *gc);
-gboolean qq_can_receive_file(GaimConnection *gc, const char *who);
-void qq_send_file(GaimConnection *gc, const char *who, const char *file);
+		guint32 sender_uid, PurpleConnection *gc);
+gboolean qq_can_receive_file(PurpleConnection *gc, const char *who);
+void qq_send_file(PurpleConnection *gc, const char *who, const char *file);
 void qq_get_conn_info(guint8 *data, guint8 **cursor, gint data_len, ft_info *info);
 gint qq_fill_conn_info(guint8 *data, guint8 **cursor, ft_info *info);
-gssize _qq_xfer_write(const guint8 *buf, size_t len, GaimXfer *xfer);
+gssize _qq_xfer_write(const guint8 *buf, size_t len, PurpleXfer *xfer);
 
 #endif
@@ -1,9 +1,9 @@
  *
- * Gaim is the legal property of its developers, whose names are too numerous
+ * Purple is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.